# instagrapi
Fast and effective Instagram Private API wrapper (public+private requests and challenge resolver)


### Install

    pip install instagrapi

### Tests

    python -m unittest tests
    python -m unittest tests.ClientPublicTestCase